@@ -409,6 +409,7 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def get_resource(
@@ -424,6 +425,13 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
@@ -581,6 +589,13 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
@@ -738,6 +753,13 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
@@ -895,6 +917,13 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
@@ -1052,6 +1081,13 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
