@@ -18,8 +18,8 @@ import os
 # try/except added for compatibility with python < 3.8
 try:
     from unittest import mock
-    from unittest.mock import AsyncMock
-except ImportError:
+    from unittest.mock import AsyncMock  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
     import mock
 
 import math
@@ -35,6 +35,7 @@ from google.oauth2 import service_account
 from google.protobuf import any_pb2  # type: ignore
 import grpc
 from grpc.experimental import aio
+from proto.marshal.rules import wrappers
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 import pytest
 
@@ -223,6 +224,7 @@ def test_gateway_service_client_client_options(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -240,6 +242,7 @@ def test_gateway_service_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -257,6 +260,7 @@ def test_gateway_service_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -286,6 +290,25 @@ def test_gateway_service_client_client_options(
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -353,6 +376,7 @@ def test_gateway_service_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -387,6 +411,7 @@ def test_gateway_service_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -409,6 +434,7 @@ def test_gateway_service_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -523,6 +549,7 @@ def test_gateway_service_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -561,6 +588,7 @@ def test_gateway_service_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -581,6 +609,7 @@ def test_gateway_service_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -619,6 +648,7 @@ def test_gateway_service_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -755,7 +785,9 @@ def test_get_resource_from_dict_foreign():
             request={
                 "content_type": "content_type_value",
                 "data": b"data_blob",
-                "extensions": [any_pb2.Any(type_url="type_url_value")],
+                "extensions": [
+                    any_pb2.Any(type_url="type.googleapis.com/google.protobuf.Empty")
+                ],
             }
         )
         call.assert_called()
@@ -866,7 +898,9 @@ def test_post_resource_from_dict_foreign():
             request={
                 "content_type": "content_type_value",
                 "data": b"data_blob",
-                "extensions": [any_pb2.Any(type_url="type_url_value")],
+                "extensions": [
+                    any_pb2.Any(type_url="type.googleapis.com/google.protobuf.Empty")
+                ],
             }
         )
         call.assert_called()
@@ -977,7 +1011,9 @@ def test_delete_resource_from_dict_foreign():
             request={
                 "content_type": "content_type_value",
                 "data": b"data_blob",
-                "extensions": [any_pb2.Any(type_url="type_url_value")],
+                "extensions": [
+                    any_pb2.Any(type_url="type.googleapis.com/google.protobuf.Empty")
+                ],
             }
         )
         call.assert_called()
@@ -1088,7 +1124,9 @@ def test_put_resource_from_dict_foreign():
             request={
                 "content_type": "content_type_value",
                 "data": b"data_blob",
-                "extensions": [any_pb2.Any(type_url="type_url_value")],
+                "extensions": [
+                    any_pb2.Any(type_url="type.googleapis.com/google.protobuf.Empty")
+                ],
             }
         )
         call.assert_called()
@@ -1199,7 +1237,9 @@ def test_patch_resource_from_dict_foreign():
             request={
                 "content_type": "content_type_value",
                 "data": b"data_blob",
-                "extensions": [any_pb2.Any(type_url="type_url_value")],
+                "extensions": [
+                    any_pb2.Any(type_url="type.googleapis.com/google.protobuf.Empty")
+                ],
             }
         )
         call.assert_called()
@@ -1428,6 +1468,28 @@ def test_gateway_service_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.GatewayServiceGrpcTransport,
+        transports.GatewayServiceGrpcAsyncIOTransport,
+    ],
+)
+def test_gateway_service_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1870,4 +1932,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
